Momoko — Momoko 1.1.6 documentation

### Navigation

- index
- modules |
- next |
- Momoko 1.1.6 documentation »

# Momoko

Momoko wraps Psycopg2‘s functionality for use in Tornado.

The latest source code can be found on Github and bug reports can be sent there too. All releases will be uploaded to PyPi.

Contents:

- Changelog
- Installation
- Tutorial
- API

## Indices and tables

- Index
- Search Page

### Navigation

- index
- modules |
- next |
- Momoko 1.1.6 documentation »